from setuptools import setup, find_packages
import codecs
import os

VERSION = '6.0'
DESCRIPTION = 'helpfull tools'
long_description = 'helpfull tools'
setup(
    name='GuziX',
    version=VERSION,
    author='Chanakya Ram Sai Illa',
    author_email='Chanakyaramsaiilla@gmail.com',
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['numpy'],
    keywords=['grids', 'gtools'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)